function StatusBox(position, size, status, background, borderColour, borderWidth, darkenBackground, titleText, titleSize, titleColour, titleFont, textSize, textFont, buttonSize, buttonTextSize) {

    this.position = position;
    this.size = size;
    this.status = status;
    this.bgColour = background;
    this.borderColour = borderColour;
    this.borderWidth = borderWidth;
    this.darkenBg = darkenBackground;
    this.titleText = titleText;
    this.titleSize = titleSize;
    this.titleColour = titleColour;
    this.titleFont = titleFont;
    this.textSize = textSize;
    this.textFont = textFont;

    this.isVisible = false;
    this.isChain = false;

    var poData = {
        size: new Vector2(210, 100),
        title: "Sell your shop",
        titleSize: 16,
        price: undefined,
        text: "Your loyal customers will stay with you but you'll lose everything else. Your total money earned and total customers served also won't reset.",
        textSize: 14,
        bgColour: "#000",
        textColour: "#FFF"
    };

    this.btnSell = new UpgradeButton(
        new Vector2(620, 149),
        new Vector2(30, 30),
        "#FD5",
        undefined,
        "$",
        undefined,
        24, "#000", undefined,
        "#FA5", 1,
        poData);

    this.btnSell.btn.onclick = function () {
        self.onsell();
    }
    this.btnSell.isVisible = true;
    this.btnSell.isSmall = true;

    var buttonPos = this.position.copy().add(new Vector2((this.size.x - buttonSize.x) / 2, this.size.y * 2 / 3 + 45));
    this.btnClose = new Button(buttonPos, buttonSize, "#55F", "Close", buttonTextSize, "#FFF", this.titleFont, "#5517A6", 2);
    this.btnClose.onclick = function () {
        self.close();
        return true;
    }

    var self = this;

    this.close = function () {
        if (typeof self.onclose === 'function') {
            self.onclose(this.input);
        }
    }

    this.willAppear = function () {
        this.btnClose.willAppear();
        this.btnSell.willAppear();
        if (this.isChain) {
            this.btnSell.popOver.title = this.btnSell.popOver.title.replace("shop", "chain");
        }
    }

    this.willDisappear = function () {
        this.btnClose.willDisappear();
        this.btnSell.willDisappear();
    }
}

StatusBox.prototype.render = function (screen) {
    var oldAlpha = screen.alpha;

    if (this.darkenBg) {
        screen.alpha = 0.80;
        screen.renderFilledRect(new Vector2(), screen.size, "#000");
    }

    screen.alpha = 1.0;

    // Render the background.
    var pos = this.position.copy().add(
        new Vector2(this.borderWidth / 2, this.borderWidth / 2));
    var size = this.size.copy().add(
        new Vector2(-this.borderWidth, -this.borderWidth));
    screen.renderFilledRect(pos,
        size,
        this.bgColour);

    // Render the border.
    if (this.borderWidth > 0) {
        screen.renderRect(this.position,
            this.size,
            this.borderWidth,
            this.borderColour);
    }

    var textMargin = new Vector2(this.borderWidth * 3, this.borderWidth * 3 + this.titleSize);

    // Render the title.
    var titlePosition = this.position.copy().add(textMargin);
    var maxWidth = this.size.x - 2 * textMargin.x;

    screen.renderText(this.titleText,
        titlePosition,
        this.titleSize,
        this.titleColour,
        this.titleFont,
        maxWidth);

    titlePosition.add(new Vector2(20, textMargin.y + this.titleSize - 1.5 * this.textSize));

    var statusText = "Total Money Earned (This " //
        + (this.isChain ? "chain" : "shop") + "): " //
        + Math.floor(this.status.newTotalMoney) + "\n\
Total Money Earned (Globally): " + Math.floor(this.status.totalMoney) + "\n\
Total Customers Served (This " //
        + (this.isChain ? "chain" : "shop") + "): " //
        + Math.floor(this.status.newTotalCustomers) + "\n\
Total Customers Served (Globally): " + Math.floor(this.status.totalCustomers) + "\n\
New Loyal Customers Made This " //
        + (this.isChain ? "Chain" : "Shop") + ": " //
        + Math.floor(this.status.loyalCustomers) + "\n\
    Loyal Customers(Globally): " + Math.floor(this.status.totalLoyalCustomers) + "\n\
Number of " + (this.isChain ? "Chains" : "Shops") + " Sold: " + this.status.numberOfShopsSold;

    if (this.status.speedUp > 1) {
        statusText = statusText + "\nLoyal Customer Bonus: x" //
            + Math.floor(this.status.speedUp);
    }

    screen.renderText(statusText,
        titlePosition,
        this.textSize,
        this.titleColour,
        this.textFont,
        maxWidth,
        undefined, undefined, undefined, undefined,
        true,
        8);

    var INV_SPEED = 2000;
    var time = new Date().getTime() % INV_SPEED;
    var slowPulse = (time / (INV_SPEED / 2)) - 1;
    slowPulse *= slowPulse;
    
    var possSpeedUp = Math.floor(this.status.getSpeedUp(this.status.totalLoyalCustomers));
    if (possSpeedUp >= 1.5 * this.status.speedUp) {
        var g = ["8","9","A","B","C","D","E"];
        g = g[Math.floor(g.length * slowPulse)];
        this.btnSell.btn.textColour = "#0" + g + "0";
    }

    this.btnSell.render(screen);
    this.btnClose.render(screen, undefined, "#000", "#000");

    screen.alpha = oldAlpha;
}